#
# spec file for package baka-mplayer
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           baka-mplayer
Version:        2.0.4
Release:        5.10
Summary:        A media player with UI using libmpv
License:        Apache-2.0 AND GPL-2.0-or-later
URL:            http://bakamplayer.u8sand.net/
Source0:        https://github.com/u8sand/Baka-MPlayer/archive/v%{version}.tar.gz#/Baka-MPlayer-%{version}.tar.gz
Patch0:         ceil.patch
# PATCH-FIX-UPSTREAM Fix build with mpv 2.0 gh#u8sand/Baka-MPlayer#317
Patch1:         Port-away-from-deprecated-removed-APIs-in-mpv-2.0.patch
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-common-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(mpv)

%description
Baka MPlayer is a libmpv-based multimedia player. It supports gesture
seeking, desktop dimming, hardware accelerated playback (vdpau,
vaapi, vda) and Youtube playback support (and others).

%prep
%setup -q -n Baka-MPlayer-%{version}
%autopatch -p1

%build
%qmake5 src/Baka-MPlayer.pro CONFIG+="release install_translations man.extra" \
    lupdate=lupdate-qt5 lrelease=lrelease-qt5  \
    DOCDIR=%{_docdir}

%make_jobs

%install
%qmake5_install
%suse_update_desktop_file %{name} AudioVideo Video Player

%files
%license LICENSE
%doc DOCS/%{name}.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/pixmaps/%{name}.svg
%{_datadir}/icons/hicolor/scalable
%{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/%{name}

%changelog
* Mon Feb 21 2022 Fusion Future <qydwhotmail@gmail.com>
- Fix build with mpv 2.0 (gh#mpv-player/mpv#9541, gh#u8sand/Baka-MPlayer#317)
  * Port-away-from-deprecated-removed-APIs-in-mpv-2.0.patch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Thu Oct 25 2018 Ondřej Súkup <mimi.vx@gmail.com>
- cleanup specfile
* Tue Mar 21 2017 olaf@aepfle.de
- Remove Category "Utilities" from desktop file
* Thu Mar  2 2017 jengelh@inai.de
- Throw out NPOV wording and instead mention a number of
  real features.
* Wed Feb 22 2017 mimi.vx@gmail.com
- import from packman
* Tue Jan 19 2016 aloisio@gmx.com
- Update to version 2.0.4
  * New: Highly requested Hide All Controls mode (under
    Settings menu)
  * New: Ability to add external audio files
  * New: Option to not save recently opened files
  * New: Option to not restore playback position
  * New: Option to change mpv msg-level
  * New: "clear" command
  * New: Explain how to leave full screen mode
  * New: Message is displayed for Motion Interpolation &
    Deinterlace options
  * New: Media Info displays if hwdec is in use or not
  * Fixed: Reordering playlist items would make them disappear
    (Windows only)
  * Fixed: Show message if file couldn't be opened
  * Fixed: An issue with resuming playback position
  * Fixed: Hide Album Art fully hides that portion
  * Fixed: Command line output is no longer double spaced
  * Changed: Double click a Key Binding entry to change it
  * Changed: Renamed an item to Open Copied Link
  * Changed: Cmd line shortcut key is now Ctrl+`
  * Changed: Cmd line no longer requires "debug debug" to show
    output
  * Changed: Gesture info is visually represented
  * Changed: Button text case to Sane Case
* Mon Jul  6 2015 liujianfeng1994@gmail.com
- Update to version 2.0.3
  * Hint: If you speed up the video, Baka will display how much real time you have remaining.
  * Fixed: Status info is now displayed with audio files without album art
  * Fixed: Disable Show in Folder for online files
  * Fixed: Key Bindings table is, and can be, sorted alphabetically
  * Changed: Logo :D
  * Changed: Settings file uses JSON
  * Changed: Currently playing file is selected in playlist (old behavior)
  * Changed: External subtitles will be labeled as so
  * Changed: Volume level shown on mouse scroll
  * Changed: Speed is increased/decreased by interval of 10%%
  * Changed: Sub font size is increased/decreased by 0.1
  * Improved: Overall design
  * Improved: Playback Info display
  * Added: Croatian translation
  * Added: Dutch translation
  * Added: French translation
  * Added: Spanish translation
  * Added: Mute (different from setting volume to 0)
  * Added: Thumbnail buttons (Windows only)
  * Added: Metadata (ex. ID3 Tags) to playback info
  * Added: Delete external sub file along with video file (optional)
  * Added: Motion Interpolation option (previously called "smoothmotion")
  * Added: "help" command
* Thu Feb 12 2015 aloisio@gmx.com
- Update to version 2.0.2
  * Fixed: Dim Desktop on multiple platforms
  * Fixed: Playing files located in the root directory (Windows only)
  * Fixed: Show parent folder under recently opened list (Windows only)
  * Fixed: Show in Folder selects file (Windows only)
  * Fixed: Gesture sensitivity is resolution independent
  * Changed: Custom settings implementation
  * Changed: File info shows up as overlay
  * Changed: Some default key-bindings for easier workflow
  * Improved: Major code refracting for efficiency
  * Improved: Playlist
  * Improved: Fit Window
  * Improved: Settings
  * Improved: Multiple-monitor support
  * Improved: Tweaked interface colors for better visibility
  * Added: Italian translation
  * Added: Support for custom keyboard shortcuts
  * Added: Playlist will auto show if cursor is near it in full screen
  * Added: Automatic Updating (Windows only)
  * Added: Command-Line engine
  * Added: Support for easily updating youtube-dl
* Thu Jan  1 2015 aloisio@gmx.com
- Added support for $RPM_OPT_FLAGS
* Mon Dec 29 2014 aloisio@gmx.com
- updated to version 2.0.1
  * Fixed: Spacing in debug window output
  * Fixed: Some issue with loading mpv settings
  * Fixed: Desktop file for better platform integration
  * Changed: Build system from CMake to QMake
  * Changed: Some menu item shortcut keys
  * Changed: Increased seekbar height
  * Changed: Fast seeking
  * Changed: Do not save window size into settings
  * Added: Youtube video playback support (and others)
  * Added: Ability to open directories
  * Added: Recently opened file list
  * Added: Interact with mpv directly via command line interface
  * Added: Fit Window 150%%
  * Added: Gesture Support
    Click & drag cursor up/down to change volume
    Click & drag cursor left/right to seek
  * Playlist
    Search is now case-insensitive
    Up/Down Arrow keys navigate, Enter plays
    Currently playing item is bolded
  * Added Translations
    Chinese
    Korean
    Portuguese
    Russian
* Mon Dec  1 2014 edogawa@aon.at
- stop using %%cmake, fixes the unresolvable requirement for libmainwindow.so
* Mon Nov 24 2014 scarabeus@opensuse.org
- Fix desc/summary to not be mpv
* Mon Nov 24 2014 scarabeus@opensuse.org
- Initial commit. Player using libmpv as its backend.
